CwComponentsBatchError

Enum CwComponentsBatchError 

pub enum CwComponentsBatchError {
    InvalidInstrument {
        reason: CwError,
    },
    InvalidComponents {
        reason: WavelengthComponentsError,
    },
    ReferenceWavelengthMismatch,
    InvalidComponentPosition {
        reflection: usize,
        component: usize,
    },
    InvalidComponentProfile {
        reflection: usize,
        component: usize,
        reason: CwError,
    },
    InvalidComponentGeometry {
        reflection: usize,
        component: usize,
        reason: FcjError,
    },
    Accumulation {
        reason: ProfileError,
    },
}
Errors while accumulating a CW wavelength-component batch.

Variants



InvalidInstrument

The shared constant-wavelength instrument is invalid.

Fields

reason: CwError

Instrument validation failure.



InvalidComponents

The wavelength-component arrays are invalid.

Fields

reason: WavelengthComponentsError

Component validation failure.



ReferenceWavelengthMismatch

Component zero does not match the instrument reference wavelength.



InvalidComponentPosition

Bragg’s law cannot represent a wavelength at one reflection d-spacing.

Fields

reflection: usize

Index of the invalid reflection.

component: usize

Index of the invalid wavelength component.



InvalidComponentProfile

A component angle or its derived widths are invalid.

Fields

reflection: usize

Index of the invalid reflection.

component: usize

Index of the invalid wavelength component.

reason: CwError

Component-specific CW failure.



InvalidComponentGeometry

A component cannot be represented by the requested FCJ geometry.

Fields

reflection: usize

Index of the invalid reflection.

component: usize

Index of the invalid wavelength component.

reason: FcjError

Component-specific FCJ failure.



Accumulation

Grid, support, or allocation validation failed.

Fields

reason: ProfileError

Underlying generic profile failure.