pub struct TchShape {
pub total_fwhm: f64,
pub eta: f64,
pub d_total_fwhm_d_gaussian_fwhm: f64,
pub d_total_fwhm_d_lorentzian_fwhm: f64,
pub d_eta_d_gaussian_fwhm: f64,
pub d_eta_d_lorentzian_fwhm: f64,
}Expand description
Transformed TCH pseudo-Voigt shape and analytical width derivatives.
Fields
total_fwhm: f64Common pseudo-Voigt full width at half maximum.
eta: f64Lorentzian mixing fraction.
d_total_fwhm_d_gaussian_fwhm: f64Derivative of total FWHM with respect to Gaussian component FWHM.
d_total_fwhm_d_lorentzian_fwhm: f64Derivative of total FWHM with respect to Lorentzian component FWHM.
d_eta_d_gaussian_fwhm: f64Derivative of eta with respect to Gaussian component FWHM.
d_eta_d_lorentzian_fwhm: f64Derivative of eta with respect to Lorentzian component FWHM.
Implementations