pub enum TofIncidentSpectrumError {
InvalidRange,
NonFiniteCoefficient,
TofOutsideRange,
NonPositiveIntensity,
}Expand description
Invalid TOF incident-spectrum calibration or evaluation.
Variants
InvalidRange
The inclusive validity interval is not finite, positive, and increasing.
NonFiniteCoefficient
At least one fitted coefficient is non-finite.
TofOutsideRange
Requested TOF is non-finite or outside the inclusive validity interval.
NonPositiveIntensity
Evaluation produced an incident intensity that is not positive and finite.